@@ -56,8 +56,8 @@ namespace Pinta.Core
 			fact.AddDefault ();
 			
 			CropToSelection = new Gtk.Action ("CropToSelection", Catalog.GetString ("Crop to Selection"), null, "Menu.Image.Crop.png");
-			Resize = new Gtk.Action ("Resize", Catalog.GetString ("Resize..."), null, "Menu.Image.Resize.png");
-			CanvasSize = new Gtk.Action ("CanvasSize", Catalog.GetString ("Canvas Size..."), null, "Menu.Image.CanvasSize.png");
+			Resize = new Gtk.Action ("Resize", Catalog.GetString ("Resize Image..."), null, "Menu.Image.Resize.png");
+			CanvasSize = new Gtk.Action ("CanvasSize", Catalog.GetString ("Resize Canvas..."), null, "Menu.Image.CanvasSize.png");
 			FlipHorizontal = new Gtk.Action ("FlipHorizontal", Catalog.GetString ("Flip Horizontal"), null, "Menu.Image.FlipHorizontal.png");
 			FlipVertical = new Gtk.Action ("FlipVertical", Catalog.GetString ("Flip Vertical"), null, "Menu.Image.FlipVertical.png");
 			RotateCW = new Gtk.Action ("RotateCW", Catalog.GetString ("Rotate 90° Clockwise"), null, "Menu.Image.Rotate90CW.png");
@@ -182,14 +182,16 @@ namespace Pinta.Core
 			hist.TakeSnapshotOfImage ();
 			hist.RestorePath = doc.SelectionPath.Clone ();
 
-			PintaCore.Chrome.DrawingArea.GdkWindow.FreezeUpdates ();
+			PintaCore.Chrome.Canvas.GdkWindow.FreezeUpdates ();
 
 			double original_scale = doc.Workspace.Scale;
 			doc.ImageSize = rect.Size;
 			doc.Workspace.CanvasSize = rect.Size;
 			doc.Workspace.Scale = original_scale;
 
-			PintaCore.Chrome.DrawingArea.GdkWindow.ThawUpdates ();
+			PintaCore.Actions.View.UpdateCanvasScale ();
+
+			PintaCore.Chrome.Canvas.GdkWindow.ThawUpdates ();
 
 			foreach (var layer in doc.Layers)
 				layer.Crop (rect, doc.SelectionPath);
