@@ -29,9 +29,13 @@ using Cairo;
 using Gtk;
 using System.IO;
 using Mono.Unix;
+using Mono.Addins;
 
 namespace Pinta.Core
 {
+	public delegate void MouseHandler (double x, double y, Gdk.ModifierType state);
+
+	[TypeExtensionPoint]
 	public abstract class BaseTool
 	{
 		protected const int DEFAULT_BRUSH_WIDTH = 2;
@@ -44,6 +48,9 @@ namespace Pinta.Core
 		protected ToolItem tool_sep;
 		protected ToolBarDropDownButton antialiasing_button;
 		protected ToolBarDropDownButton alphablending_button;
+		public event MouseHandler MouseMoved;
+		public event MouseHandler MousePressed;
+		public event MouseHandler MouseReleased;
 
 		protected BaseTool ()
 		{
@@ -78,6 +85,8 @@ namespace Pinta.Core
 		#region Public Methods
 		public void DoMouseMove (object o, MotionNotifyEventArgs args, Cairo.PointD point)
 		{
+			if (MouseMoved != null)
+				MouseMoved (point.X, point.Y, args.Event.State);
 			OnMouseMove (o, args, point);
 		}
 
@@ -94,11 +103,15 @@ namespace Pinta.Core
 
 		public void DoMouseDown (DrawingArea canvas, ButtonPressEventArgs args, Cairo.PointD point)
 		{
+			if (MousePressed != null)
+				MousePressed (point.X, point.Y, args.Event.State);
 			OnMouseDown (canvas, args, point);
 		}
 
 		public void DoMouseUp (DrawingArea canvas, ButtonReleaseEventArgs args, Cairo.PointD point)
 		{
+			if (MouseReleased != null)
+				MouseReleased (point.X, point.Y, args.Event.State);
 			OnMouseUp (canvas, args, point);
 		}
 
@@ -224,7 +237,7 @@ namespace Pinta.Core
 		
 		protected void SetCursor (Gdk.Cursor cursor)
 		{
-			PintaCore.Chrome.DrawingArea.GdkWindow.Cursor = cursor;
+			//PintaCore.Chrome.DrawingArea.GdkWindow.Cursor = cursor;
 		}
 		#endregion
 
