@@ -669,6 +669,8 @@ namespace Pinta.Core
 			ImageSize = new Gdk.Size (ImageSize.Height, ImageSize.Width);
 			Workspace.CanvasSize = new Gdk.Size (Workspace.CanvasSize.Height, Workspace.CanvasSize.Width);
 
+			PintaCore.Actions.View.UpdateCanvasScale ();
+
 			Workspace.Invalidate ();
 		}
 
@@ -680,14 +682,16 @@ namespace Pinta.Core
 			ImageSize = new Gdk.Size (ImageSize.Height, ImageSize.Width);
 			Workspace.CanvasSize = new Gdk.Size (Workspace.CanvasSize.Height, Workspace.CanvasSize.Width);
 
+			PintaCore.Actions.View.UpdateCanvasScale ();
+
 			Workspace.Invalidate ();
 
 		}
 
 		// Returns true if successful, false if canceled
-		public bool Save ()
+		public bool Save (bool saveAs)
 		{
-			return PintaCore.Actions.File.RaiseSaveDocument (this);
+			return PintaCore.Actions.File.RaiseSaveDocument (this, saveAs);
 		}
 
 		public void SetCurrentLayer (int i)
