@@ -77,8 +77,9 @@ namespace Pinta.Gui.Widgets
 
 				if (PintaCore.Workspace.ActiveWorkspace.PointInCanvas (point))
 					PintaCore.Chrome.LastCanvasCursorPoint = point.ToGdkPoint ();
-					
-				PintaCore.Tools.CurrentTool.DoMouseMove (sender, e, point);
+
+				if (PintaCore.Tools.CurrentTool != null)
+					PintaCore.Tools.CurrentTool.DoMouseMove (sender, e, point);
 			};
 
 			// Handle key press/release events
@@ -196,8 +197,8 @@ namespace Pinta.Gui.Widgets
 
 		protected override bool OnScrollEvent (EventScroll evnt)
 		{
-			// Allow the user to zoom in/out with Ctrl-Mousewheel
-			if (evnt.State  == ModifierType.ControlMask) {
+			// Allow the user to zoom in/out with Ctrl-Mousewheel (as long as Shift and Alt are not also pressed)
+			if ((evnt.State & (ModifierType.ControlMask | ModifierType.ShiftMask | ModifierType.Mod1Mask)) == ModifierType.ControlMask) {
 				switch (evnt.Direction) {
 					case ScrollDirection.Down:
 					case ScrollDirection.Right:
